import { statisticsFetch } from '../../../api/fetch';
import { formatPrice } from '../../../utils/util';

// pages/components/EquipmentOperationDetails/EquipmentOperationDetails.js
Component({
  lifetimes: {
    attached() {},
  },
  /**
   * 组件的属性列表
   */
  properties: {
    totalAmount: {
      type: Array,
      value: [],
    },
    areaId: {
      type: Number,
      value: 0,
      observer() {
        this.fetchData();
        this.refreshList();
      },
    },
  },

  /**
   * 组件的初始数据
   */
  data: {
    sortTypeOptions: [
      { value: 'desc', label: '降序' },
      { value: 'asc', label: '升序' },
    ],
    sortTypeIndex: '0',
    sortType: 'desc',
    timeType: 0,
    comsumerData: {
      title: '消费总额',
      numberType: 'price',
      count: 0,
    },
    countData: {
      title: '消费笔数',
      numberType: 'count',
      count: 0,
    },
    pageNum: 1,
    pageSize: 15,
    dataList: [],
    deviceType: 3, // （2：洗衣，3：饮水，4：吹风，5：洗浴）
  },

  /**
   * 组件的方法列表
   */
  methods: {
    changeType(e) {
      console.log(e);
      const { timetype } = e.currentTarget.dataset;
      if (timetype === this.data.timeType) return;
      this.setData({
        timeType: timetype,
      });
      this.fetchData();
      this.refreshList();
    },
    fetchData() {
      statisticsFetch({
        url: '/boss/device/operation/data/summary',
        method: 'POST',
        data: {
          areaId: this.data.areaId,
          timeType: this.data.timeType,
        },
      })
        .then(res => {
          console.log(res);
          const { totalConsumeAmount, totalConsumeCount } = res.data;
          this.setData({
            'comsumerData.count': totalConsumeAmount,
            'countData.count': totalConsumeCount,
          });
        })
        .catch(err => {
          console.log(err);
        });
    },
    fetchList(entity) {
      return statisticsFetch({
        url: '/boss/device/operation/data/detail/paging',
        method: 'POST',
        data: {
          areaId: this.data.areaId,
          timeType: this.data.timeType,
          sortType: this.data.sortType,
          deviceType: this.data.deviceType,
          pageNum: this.data.pageNum,
          pageSize: this.data.pageSize,
          ...entity,
        },
      });
    },
    refreshList() {
      wx.showLoading({
        title: '加载中',
        mask: true,
      });
      this.fetchList({
        pageNum: 1,
      })
        .then(res => {
          wx.hideLoading();
          const { list } = res.data;
          this.setData({
            pageNum: 1,
            dataList: list.map(item => ({
              ...item,
              consumeAmount: formatPrice(item.consumeAmount),
            })),
          });
        })
        .catch(err => {
          wx.hideLoading();
          console.log(err);
        });
    },
    getMoreListItem() {
      wx.showLoading({
        title: '加载中',
        mask: true,
      });
      this.fetchList({
        pageNum: this.data.pageNum + 1,
      })
        .then(res => {
          wx.hideLoading();
          const list = res.data.list.map(item => ({
            ...item,
            consumeAmount: formatPrice(item.consumeAmount),
          }));
          if (list && list.length) {
            this.setData!({
              dataList: [...this.data.dataList, ...list],
              pageNum: this.data.pageNum + 1,
            });
          }
        })
        .catch(err => {
          wx.hideLoading();
          console.log(err);
        });
    },
    changeSortType(e) {
      const { value } = e.detail;
      let item = this.data.sortTypeOptions[value];
      console.log(item);
      this.setData({
        sortTypeIndex: value,
        sortType: item.value,
      });
      this.refreshList();
    },
    changeDeviceType(e) {
      console.log(e);
      const { devicetype } = e.currentTarget.dataset;
      if (devicetype === this.data.deviceType) return;
      this.setData({
        deviceType: devicetype,
      });
      this.refreshList();
    },
  },
});
