import { operatorFetch } from '../../../api/fetch';
import { IMyApp } from '../../../app';

const app = getApp<IMyApp>();
let timer = null;
let payTimer = null;
let fetchedPlatform = false;
// pages/components/PlatformFeeDialog/PlatformFeeDialog.js
Component({
  lifetimes: {
    attached() {
      console.log(app.globalData.userInfo);
      this.setData!({
        userInfo: app.globalData.userInfo,
      });
      this.data.eventType === 'slef' &&
        !fetchedPlatform &&
        this.fetchPlatformFee();
    },
  },
  /**
   * 组件的属性列表
   */
  properties: {
    eventType: { type: String, value: 'slef' },
  },

  /**
   * 组件的初始数据
   */
  data: {
    userInfo: app.globalData.userInfo,
    showDialog: false,
    type: 1, // 1 支付 2 扫码
    isSkip: 0,
    isOnlyShowPrompt: 0,
    rechargeBalance: 0,
    payTimeLimit: 0,
    billType: '0',
    payQrUrl: '',
    countDown: 600,
    countDownString: '10分00秒',
  },

  /**
   * 组件的方法列表
   */
  methods: {
    fetchPlatformFee() {
      operatorFetch({
        url: '/operateBalance/rechage/initdata',
        method: 'POST',
        data: {
          operateId: this.data.userInfo.operateId,
          operateName: this.data.userInfo.operateName,
          position: 3,
          type: 2,
        },
      })
        .then(res => {
          const {
            isSkip,
            rechargeBalance,
            payTimeLimit,
            isOnlyShowPrompt,
          } = res;
          this.setData({
            isSkip,
            rechargeBalance,
            payTimeLimit,
            showDialog: rechargeBalance > 0 ? true : false,
            isOnlyShowPrompt,
          });
          fetchedPlatform = true;
        })
        .catch(err => {
          console.log(err);
        });
    },
    cancelShow() {
      this.setData({
        showDialog: false,
      });
    },
    fetchRechargeInfo() {
      console.log('in fetchRechargeInfo');
      wx.showLoading({
        title: '',
      });
      wx.login({
        success: res => {
          if (res.code) {
            const entity = {
              billType: this.data.billType,
              isAgree: 1,
              jsCode: res.code,
              operateId: this.data.userInfo.operateId,
              operateName: this.data.userInfo.operateName,
              rechargeType: '2',
              type: 2,
            };
            operatorFetch({
              url: '/operateBalance/rechage/order/formini',
              method: 'POST',
              data: entity,
            })
              .then(res => {
                console.log(res);
                const { payInfo } = res;
                wx.requestPayment({
                  timeStamp: payInfo.timeStamp.toString(),
                  nonceStr: payInfo.nonceStr,
                  package: payInfo.package,
                  signType: payInfo.signType,
                  paySign: payInfo.paySign,
                  success: res => {
                    console.log(res);
                    wx.showToast({
                      title: '支付成功！',
                    });
                    this.setData({
                      showDialog: false,
                    });
                  },
                  fail(res) {
                    console.log(res);
                    wx.showToast({
                      title: '支付失败！',
                      icon: 'none',
                    });
                  },
                });
              })
              .catch(err => {
                console.log(err);
                wx.hideLoading();
                wx.showToast({
                  title: err.msg || '请求失败',
                  icon: 'none',
                });
              });
          } else {
            wx.hideLoading();
            wx.showToast({
              title: res.errMsg || '请求失败',
              icon: 'none',
            });
          }
        },
        fail(res) {
          wx.hideLoading();
          wx.showToast({
            title: res.errMsg || '请求失败',
            icon: 'none',
          });
        },
      });
    },
    goRecordsPage() {
      wx.navigateTo({
        url: '/pages/platformFee/platformFee',
      });
    },
    toggleType() {
      let type = this.data.type;
      this.setData({
        type: type === 1 ? 2 : 1,
      });
      if (type === 1) {
        this.fetchRechargeOrderQRcode();
      } else {
        timer && clearInterval(timer);
        this.setData({
          countDown: 600,
          countDownString: '',
        });
      }
    },
    checkBillType(e) {
      console.log(e);
      const { value } = e.currentTarget.dataset;
      if (value === this.data.billType) return;
      this.setData({
        billType: value,
      });
      if (this.data.type === 2) {
        this.fetchRechargeOrderQRcode();
      } else {
        payTimer && clearInterval(payTimer);
      }
    },
    fetchRechargeOrderQRcode() {
      wx.showLoading({
        title: '',
      });
      if (timer) {
        clearInterval(timer);
        this.setData({
          payQrUrl: '',
          countDown: 600,
          countDownString: '0秒',
        });
      }
      wx.login({
        success: res => {
          if (res.code) {
            const entity = {
              billType: this.data.billType,
              isAgree: 1,
              jsCode: res.code,
              operateId: this.data.userInfo.operateId,
              operateName: this.data.userInfo.operateName,
              rechargeType: '2',
              type: 2,
            };
            operatorFetch({
              url: '/operateBalance/rechage/order/forcodeimg',
              method: 'POST',
              data: entity,
            })
              .then(res => {
                wx.hideLoading();
                const { payQrUrl, orderNum } = res;
                this.setData({
                  payQrUrl,
                });
                timer = setInterval(() => {
                  let count = this.data.countDown;
                  if (count === 0) {
                    clearInterval(timer);
                    this.setData({
                      payQrUrl: '',
                      countDown: 600,
                      countDownString: '0秒',
                    });
                  } else {
                    let newCount = count - 1;
                    let countString =
                      Math.floor(newCount / 60) + '分' + (newCount % 60) + '秒';
                    this.setData({
                      countDown: newCount,
                      countDownString: countString,
                    });
                  }
                }, 1000);
                payTimer = setInterval(() => {
                  console.log('in setInterval');
                  operatorFetch({
                    url: '/operateBalance/rechage/sure',
                    method: 'POST',
                    data: { orderNum: orderNum },
                  })
                    .then(res => {
                      const { rechargeState } = res;
                      if (rechargeState === '1') {
                        wx.showToast({
                          title: res.msg || '',
                          icon: 'success',
                        });
                        clearInterval(payTimer);
                        this.setData({
                          showDialog: false,
                        });
                      }
                    })
                    .catch(err => {
                      console.log(err);
                    });
                }, 3000);
              })
              .catch(err => {
                wx.hideLoading();
                wx.showToast({
                  title: err.msg || '请求失败',
                  icon: 'none',
                });
                console.log(err);
              });
          } else {
            wx.hideLoading();
            wx.showToast({
              title: res.errMsg || '请求失败',
              icon: 'none',
            });
          }
        },
        fail(res) {
          console.log(res);
          wx.hideLoading();
          wx.showToast({
            title: res.errMsg || '请求失败',
            icon: 'none',
          });
        },
      });
    },
  },
});
